'use strict';

const { postJSON, getData } = require('./util');

/**
 * 选用订阅消息模板
 * 
 * @param {String} tid 模板标题id
 * @param {Array.<number>} kidList 模板关键词列表
 * @param {string} sceneDesc 服务场景描述
 * @returns 
 */
exports.addSubscribeMessage = async function (tid, kidList, sceneDesc) {
    const { accessToken } = await this.ensureAccessToken();
    var apiUrl = this.basePrefix + 'wxaapi/newtmpl/addtemplate?access_token=' + accessToken;
    var template = {
        tid: tid,
        kidList: kidList,
        sceneDesc: sceneDesc,
    };
    return this.request(apiUrl, postJSON(template));
};

/**
 * 删除订阅消息模板
 * 
 * @param {String} priTmplId 模板id
 * @returns 
 */
 exports.delSubscribeMessage = async function (priTmplId) {
    const { accessToken } = await this.ensureAccessToken();
    var apiUrl = this.basePrefix + 'wxaapi/newtmpl/deltemplate?access_token=' + accessToken;
    var template = {
        priTmplId: priTmplId,
    };
    return this.request(apiUrl, postJSON(template));
};

/**
 * 获取订阅消息模板关键词列表
 * 
 * @param {String} tid 模板标题id
 * @returns 
 */
 exports.getSubscribeMessageContent = async function (tid) {
    const { accessToken } = await this.ensureAccessToken();
    var apiUrl = this.basePrefix + 'wxaapi/newtmpl/getpubtemplatekeywords?access_token=' + accessToken + '&tid=' + tid;
    return this.request(apiUrl, getData());
};


/**
 * 获取已有订阅消息模板列表
 * 
 * @returns 
 */
 exports.getSubscribeMessageList = async function () {
    const { accessToken } = await this.ensureAccessToken();
    var apiUrl = this.basePrefix + 'wxaapi/newtmpl/gettemplate?access_token=' + accessToken;
    return this.request(apiUrl, getData());
};



/**
 * 发送订阅消息
 * Examples:
 * ```
 * var templateId: '模板id';
 * var page: '';
 * var data = {    
          character_string1: { value: '223' },
          thing5: { value: '测试商品' },
          date3: { value: '2020年1月1日' },
          number6: { value: '2342375986' },
          character_string9: { value: 'sf686539' },
        },
 * api.sendSubscribeMessage('openid', templateId, page, data);
 * ```
 * @param {String} openid 用户的openid
 * @param {String} templateId 模板ID
 * @param {String} page 点击模板卡片后的跳转页面，仅限本小程序内的页面。支持带参数,（示例index?foo=bar）。该字段不填则模板无跳转。
 * @param {Object} miniprogram 小程序
 * @param {Object} data 渲染模板的数据
 */
exports.sendSubscribeMessage = async function (openid, templateId, page, miniprogram, data) {
  const { accessToken } = await this.ensureAccessToken();
  var apiUrl = this.prefix + 'message/subscribe/bizsend?access_token=' + accessToken;
  var template = {
    touser: openid,
    template_id: templateId,
    page: page,
    miniprogram: miniprogram,
    data: data
  };
  return this.request(apiUrl, postJSON(template));
};

